@@ -125,31 +125,31 @@ def cli(
         return 0
     warn_in_virtualenv()
     if ctx.invoked_subcommand is None:
-        # --where was passed…
+        # --where was passed...
         if where:
             do_where(bare=True)
             return 0
         elif py:
             do_py()
             return 0
-        # --support was passed…
+        # --support was passed...
         elif support:
             from ..help import get_pipenv_diagnostics
 
             get_pipenv_diagnostics()
             return 0
-        # --clear was passed…
+        # --clear was passed...
         elif state.clear:
             do_clear()
             return 0
-        # --venv was passed…
+        # --venv was passed...
         elif venv:
             # There is no virtualenv yet.
             if not project.virtualenv_exists:
                 echo(
                     "{}({}){}".format(
                         crayons.red("No virtualenv has been created for this project"),
-                        crayons.white(project.project_directory, bold=True),
+                        crayons.normal(project.project_directory, bold=True),
                         crayons.red(" yet!")
                     ),
                     err=True,
@@ -158,7 +158,7 @@ def cli(
             else:
                 echo(project.virtualenv_location)
                 return 0
-        # --rm was passed…
+        # --rm was passed...
         elif rm:
             # Abort if --system (or running in a virtualenv).
             from ..environments import PIPENV_USE_SYSTEM
@@ -174,7 +174,7 @@ def cli(
                 loc = project.virtualenv_location
                 echo(
                     crayons.normal(
-                        u"{0} ({1})…".format(
+                        u"{0} ({1})...".format(
                             crayons.normal("Removing virtualenv", bold=True),
                             crayons.green(loc),
                         )
@@ -193,7 +193,7 @@ def cli(
                     err=True,
                 )
                 ctx.abort()
-    # --two / --three was passed…
+    # --two / --three was passed...
     if (state.python or state.three is not None) or state.site_packages:
         ensure_project(
             three=state.three,
@@ -563,11 +563,11 @@ def update(
     if not packages:
         echo(
             "{0} {1} {2} {3}{4}".format(
-                crayons.white("Running", bold=True),
-                crayons.red("$ pipenv lock", bold=True),
-                crayons.white("then", bold=True),
-                crayons.red("$ pipenv sync", bold=True),
-                crayons.white(".", bold=True),
+                crayons.normal("Running", bold=True),
+                crayons.yellow("$ pipenv lock", bold=True),
+                crayons.normal("then", bold=True),
+                crayons.yellow("$ pipenv sync", bold=True),
+                crayons.normal(".", bold=True),
             )
         )
     else:
@@ -664,6 +664,7 @@ def run_open(state, module, *args, **kwargs):
     short_help="Installs all packages specified in Pipfile.lock.",
     context_settings=CONTEXT_SETTINGS
 )
+@system_option
 @option("--bare", is_flag=True, default=False, help="Minimal output.")
 @sync_options
 @pass_state
@@ -691,6 +692,7 @@ def sync(
         unused=unused,
         sequential=state.installstate.sequential,
         pypi_mirror=state.pypi_mirror,
+        system=state.system
     )
     if retcode:
         ctx.abort()
@@ -714,5 +716,26 @@ def clean(ctx, state, dry_run=False, bare=False, user=False):
              system=state.system)
 
 
+@cli.command(
+    short_help="Lists scripts in current environment config.",
+    context_settings=subcommand_context_no_interspersion,
+)
+@common_options
+@argument("args", nargs=-1)
+@pass_state
+def scripts(state, args):
+    """Lists scripts in current environment config."""
+    from ..core import project
+    if not project:
+        echo(u"project not found", err=True)
+        exit(1)
+    scripts = project.parsed_pipfile.get('scripts', {})
+    rpt = u"command\tscript\n"
+    for k, v in scripts.items():
+        rpt += u"{0}\t{1}".format(k, v)
+    echo(rpt)
+    return 0
+
+
 if __name__ == "__main__":
     cli()
